@@ -86,6 +86,8 @@ class Image:
         self.image_analysis = image_analysis
         # 获取主商品
         self.crop_point = self.deal_crop_key_point()
+        # 获取图片背景图
+        self.image_background = self.deal_image_background()
 
         self.image_detail = ImageDetail()
         self.detail_point = {}  # {'裁剪模特帽子':{},}
@@ -324,6 +326,24 @@ class Image:
             # logging.error(f"图片{self.filename}, 分类解析失败: {e}", exc_info=True)
             return '未识别'
 
+    def deal_image_background(self):
+        """
+        background : 0 不限 1 透明 2 白底 3 其他背景
+        :return:
+        """
+        background_mapping = {
+            "transparent": 1,
+            "white": 2,
+            "None": 3,
+        }
+        image_background = 0
+
+        if self.image_analysis.get('recognition'):  # 新版本ai识别结果,存在主商品
+            recognition = json.loads(self.image_analysis["recognition"])
+            image_background = background_mapping.get(recognition.get("background"), 0)
+
+        return image_background
+
     def deal_crop_key_point(self, cloth_classify=(1, 2, 3, 4, 5), main_product_crop=None):
         '''
         cloth_classify 当前详情页 图片分类是 上身 下身 全身
