@@ -17,6 +17,8 @@ class ShouldIndex:
             # 上下裁剪点是否存在
             'top_point': False,
             'bottom_point': False,
+            # 图片背景
+            'image_background': 0,
         }
 
     def expected_crop_result(self):
@@ -109,13 +111,17 @@ class ShouldIndex:
 
     def get_top_and_bottom_padding(self, top, padding_top, bottom, padding_bottom):
         """获取 上下 padding占比 """
-        if top >= padding_top:
+        if padding_top == 0:
+            top_padding_ratio = 1
+        elif top >= padding_top:  # 上裁剪点 距离图片顶部 大于 上padiing
             top_padding_ratio = 1
         else:
             top_padding_ratio = top / padding_top
         self.crop_indexing_dict['top_padding_ratio'] = top_padding_ratio
 
-        if bottom + padding_bottom <= 1:
+        if padding_bottom == 0:
+            bottom_padding_ratio = 1
+        elif bottom + padding_bottom <= 1:
             bottom_padding_ratio = 1
         else:
             bottom_padding_ratio = (1 - bottom) / padding_bottom
@@ -168,6 +174,8 @@ class ImageCrop:
             return self.__gif_crop(slot_width, slot_height, img)
 
         self.si.get_slot_and_img_ration(slot_width / slot_height, img.ratio)
+        # 图片背景
+        self.si.crop_indexing_dict['image_background'] = img.image_background
 
         # 是否需要裁剪
         need_crop = crop_info.get(NEED_CROP)
